@@ -56,8 +56,8 @@ class Model:
             "namespace": "",
         },
     )
-    pose: "Model.Pose" = field(
-        default="0 0 0 0 0 0",
+    pose: Optional["Model.Pose"] = field(
+        default=None,
         metadata={
             "type": "Element",
             "namespace": "",
@@ -147,8 +147,8 @@ class Model:
             world frame.
         """
 
-        pose: "Model.Frame.Pose" = field(
-            default="0 0 0 0 0 0",
+        pose: Optional["Model.Frame.Pose"] = field(
+            default=None,
             metadata={
                 "type": "Element",
                 "namespace": "",
@@ -180,7 +180,7 @@ class Model:
             """
 
             value: str = field(
-                default="",
+                default="0 0 0 0 0 0",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -204,7 +204,7 @@ class Model:
         """
 
         value: str = field(
-            default="",
+            default="0 0 0 0 0 0",
             metadata={
                 "required": True,
                 "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -276,8 +276,8 @@ class Model:
                 "namespace": "",
             },
         )
-        pose: "Model.Link.Pose" = field(
-            default="0 0 0 0 0 0",
+        pose: Optional["Model.Link.Pose"] = field(
+            default=None,
             metadata={
                 "type": "Element",
                 "namespace": "",
@@ -303,7 +303,7 @@ class Model:
             """
 
             value: str = field(
-                default="",
+                default="0 0 0 0 0 0",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -337,7 +337,7 @@ class State:
     class Meta:
         name = "state"
 
-    sim_time: float = field(
+    sim_time: str = field(
         default="0 0",
         metadata={
             "type": "Element",
@@ -345,7 +345,7 @@ class State:
             "required": True,
         },
     )
-    wall_time: float = field(
+    wall_time: str = field(
         default="0 0",
         metadata={
             "type": "Element",
@@ -353,7 +353,7 @@ class State:
             "required": True,
         },
     )
-    real_time: float = field(
+    real_time: str = field(
         default="0 0",
         metadata={
             "type": "Element",
@@ -463,8 +463,8 @@ class State:
         name: Name of the light
         """
 
-        pose: "State.Light.Pose" = field(
-            default="0 0 0 0 0 0",
+        pose: Optional["State.Light.Pose"] = field(
+            default=None,
             metadata={
                 "type": "Element",
                 "namespace": "",
@@ -490,7 +490,7 @@ class State:
             """
 
             value: str = field(
-                default="",
+                default="0 0 0 0 0 0",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
