@@ -52,6 +52,7 @@ Basic functions
     Link
     InvertLink
     CustomLink
+    CompundLink
 
 
 Affine Transformations
@@ -85,6 +86,7 @@ from .base import (
     Link,
     CustomLink,
     InvertLink,
+    CompundLink,
 )
 
 from .functions import (
@@ -111,8 +113,7 @@ __all__ = [
     "Link",
     "CustomLink",
     "InvertLink",
-    "coordinates",
-    "projections",
+    "CompundLink",
     # Affine Links
     "Translation",
     "Rotation",
